@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/dialog.cc 
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -59,47 +59,6 @@ static bool on_destroy (G_GNUC_UNUSED GtkWidget *widget, Dialog* pBox)
 	return true;
 }
 
-/*Dialog::Dialog (Application* App, const char* filename, const char* windowname, DialogOwner *owner, void (*extra_destroy)(gpointer), gpointer data): UIBuilder (NULL, NULL)
-{
-	m_App = App;
-	m_Owner = owner;
-	if (owner && !owner->AddDialog (windowname, this)) {
-		xml = NULL;
-		dialog = NULL;
-		m_extra_destroy = NULL;
-		return;
-	}
-	m_Owner = owner;
-	if (filename) {
-		xml = .ui_xml_new (filename, windowname, NULL);
-		m_extra_destroy = extra_destroy;
-		m_windowname = windowname;
-		m_data = data;
-		if (xml) .ui_xml_signal_autoconnect (xml);
-		dialog = GTK_WINDOW .ui_xml_get_widget(xml, windowname));
-		gtk_window_set_icon_name (dialog, App->GetIconName ().c_str ());
-		g_signal_connect (G_OBJECT (dialog), "destroy", G_CALLBACK (on_destroy), this);
-		GtkWidget* button =.ui_xml_get_widget (xml, "OK");
-		if (button) g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_OK), this);
-		button =.ui_xml_get_widget (xml, "apply");
-		if (button) g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_apply), this);
-		button =.ui_xml_get_widget (xml, "cancel");
-		if (button) g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_cancel), this);
-		button =.ui_xml_get_widget(xml, "help");
-		if (button) {
-			if (App->HasHelp ())
-				g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_help), this);
-			else
-				gtk_widget_hide (button);
-		}
-	} else {
-		xml = NULL;
-		dialog = NULL;
-		m_extra_destroy = NULL;
-		m_windowname = "";
-	}
-}*/
-
 Dialog::Dialog (Application* App, char const *filename, const char* windowname, char const *domainname, DialogOwner *owner, void (*extra_destroy)(gpointer), gpointer data) throw (std::runtime_error):
 	UIBuilder (filename, domainname)
 {
@@ -257,4 +216,23 @@ bool Dialog::GetNumber (GtkEntry *Entry, double *x, CheckType c, double min, dou
 	return true;
 }
 
+void Dialog::SetTransientFor (GtkWindow *window)
+{
+	gtk_window_set_transient_for (dialog, window);
+}
+
+void Dialog::SetRealName (char const *name, DialogOwner *owner) throw (std::runtime_error)
+{
+	if (m_Owner)
+		m_Owner->RemoveDialog (m_windowname);
+	if (owner)
+		m_Owner = owner;
+	m_windowname = name;
+	if (m_Owner && !m_Owner->AddDialog (name, this)) {
+		m_extra_destroy = NULL;
+		// do we need to set m_Owner to NULL?
+		throw std::runtime_error (_("Could not reference the new dialog."));
+	}
+}
+
 }	//	namespace gcu
