@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * spectrumdoc.cc
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,6 +29,10 @@
 #include <sstream>
 #include <iostream>
 
+#ifndef HAVE_EXP10
+#	define exp10(x) pow(10.,(x))
+#endif
+
 using namespace std;
 
 namespace gcu
@@ -83,6 +87,8 @@ SpectrumDocument::~SpectrumDocument ()
 	for (unsigned i = 0; i < variables.size (); i++)
 		if (variables[i].Values)
 			delete [] variables[i].Values;
+	if (m_View)
+		delete m_View;
 }
 
 void SpectrumDocument::Load (char const *uri, char const *mime_type)
@@ -197,18 +203,21 @@ static void parse_data_type (char const *type, struct data_type_struct &s)
 		s.variables = g_strdup (variables.c_str ());
 }
 
-char const *Types[] = {
-	"INFRARED SPECTRUM",
-	"RAMAN SPECTRUM",
-	"INFRARED PEAK TABLE",
-	"INFRARED INTERFEROGRAM",
-	"INFRARED TRANSFORMED SPECTRUM",
-	"UV-VISIBLE SPECTRUM",
-	"NMR SPECTRUM",
-	"NMR FID",
-	"NMR PEAK TABLE",
-	"NMR PEAK ASSIGNMENTS",
-	"MASS SPECTRUM"
+static struct {char const *name; SpectrumType type;} Types[] = {
+	{"INFRARED SPECTRUM", GCU_SPECTRUM_INFRARED},
+	{"RAMAN SPECTRUM", GCU_SPECTRUM_RAMAN},
+	{"INFRARED PEAK TABLE", GCU_SPECTRUM_INFRARED_PEAK_TABLE},
+	{"INFRARED INTERFEROGRAM", GCU_SPECTRUM_INFRARED_INTERFEROGRAM},
+	{"INFRARED TRANSFORMED SPECTRUM", GCU_SPECTRUM_INFRARED_TRANSFORMED},
+	{"UV-VISIBLE SPECTRUM", GCU_SPECTRUM_UV_VISIBLE},
+	{"NMR SPECTRUM", GCU_SPECTRUM_NMR},
+	{"NMR FID", GCU_SPECTRUM_NMR_FID},
+	{"NMR PEAK TABLE", GCU_SPECTRUM_NMR_PEAK_TABLE},
+	{"NMR PEAK ASSIGNMENTS", GCU_SPECTRUM_NMR_PEAK_ASSIGNMENTS},
+	{"MASS SPECTRUM", GCU_SPECTRUM_MASS},
+	{"UV-VIS SPECTRUM", GCU_SPECTRUM_UV_VISIBLE},
+	{"UV/VISIBLE SPECTRUM", GCU_SPECTRUM_UV_VISIBLE},
+	{"UV/VIS SPECTRUM", GCU_SPECTRUM_UV_VISIBLE}
 };
 
 char const *Units[] = {
@@ -615,6 +624,15 @@ static void on_transform_fid (GtkButton *btn, SpectrumDocument *doc)
 }
 */
 
+static SpectrumType get_spectrum_type_from_string (char const *buf)
+{
+	unsigned i;
+	for (i = 0; i < G_N_ELEMENTS (Types); i++)
+		if (!strcmp (Types[i].name, buf))
+		return Types[i].type;
+	return GCU_SPECTRUM_MAX;
+}
+
 #define JCAMP_PREC 1e-3 // fully arbitrary
 
 void SpectrumDocument::LoadJcampDx (char const *data)
@@ -644,7 +662,7 @@ parse_line:
 		case JCAMP_JCAMP_DX:
 			break;
 		case JCAMP_DATA_TYPE:
-			m_SpectrumType = (SpectrumType) get_spectrum_data_from_string (buf, Types, GCU_SPECTRUM_MAX);
+			m_SpectrumType = get_spectrum_type_from_string (buf);
 			break;
 		case JCAMP_DATACLASS:
 		case JCAMP_APPLICATION:
@@ -1385,7 +1403,7 @@ out:
 		g_signal_handler_unblock (m_XAxisInvertBtn, m_XAxisInvertSgn);
 	}
 	m_View->SetAxisBounds (GOG_AXIS_X, minx, maxx, invert_axis);
-	m_View->SetAxisBounds (GOG_AXIS_Y, miny, maxy, invert_axis);
+	m_View->SetAxisBounds (GOG_AXIS_Y, miny, maxy, false);
 	if (hide_y_axis)
 		m_View->ShowAxis (GOG_AXIS_Y, false);
 	/* Add axes labels */
@@ -2014,6 +2032,9 @@ void SpectrumDocument::OnShowIntegral ()
 				v.Values[i] -= res[4] * (acc *= cur);
 				v.Values[i] -= res[5] * cur * acc;
 			}
+			if (xo[1] > xo[0])
+				for (i = 0; i < v.NbValues; i++)
+					v.Values[i] = -v.Values[i];
 			g_free (reg.se);
 			g_free (reg.t);
 			g_free (reg.xbar);
